package Locale::CLDR::Kl::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 11:29:48 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Kl');

no Moose;
__PACKAGE__->meta->make_immutable;
